@@ -94,8 +94,8 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
             while high_bit and i < 9:
                 high_bit = chunk[p] >> 7
                 value = \
-                    ((value << 8) + chunk[p + i]) if i == 8 else \
-                    ((value << 7) + (chunk[p + i] & 0x7F))
+                    ((value << 8) + chunk[p]) if i == 8 else \
+                    ((value << 7) + (chunk[p] & 0x7F))
 
                 i += 1
                 p += 1
@@ -134,7 +134,6 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
     yield_all, yield_num, get_num, return_unused = get_byte_readers(sqlite_chunks)
 
     header = get_num(100)
-    total_bytes = len(header)
 
     if header[:16] != b'SQLite format 3\0':
         raise ValueError('Magic SQLite header string not found')
@@ -155,27 +154,36 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
 
     def yield_page_cells(page_nums_pages_readers):
 
-        def _yield_cells(pointers):
+        def _yield_leaf_table_cells(page_bytes, pointers):
             for i in range(0, len(pointers) - 1):
                 cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes[pointers[i]:pointers[i + 1]])
 
-                if page_type == LEAF_TABLE:
-                    payload_size, _ = cell_varint_reader()
-                    rowid, _ = cell_varint_reader()
+                payload_size, _ = cell_varint_reader()
+                rowid, _ = cell_varint_reader()
 
-                    header_remaining, header_varint_size = cell_varint_reader()
-                    header_remaining -= header_varint_size
+                header_remaining, header_varint_size = cell_varint_reader()
+                header_remaining -= header_varint_size
 
-                    serial_types = []
-                    while header_remaining:
-                        h, v_size = cell_varint_reader()
-                        serial_types.append(h)
-                        header_remaining -= v_size
+                serial_types = []
+                while header_remaining:
+                    h, v_size = cell_varint_reader()
+                    serial_types.append(h)
+                    header_remaining -= v_size
 
-                    yield [
-                        parse_serial_value(serial_type, cell_num_reader(type_length(serial_type)))
-                        for serial_type in serial_types
-                    ]
+                yield [
+                    parse_serial_value(serial_type, cell_num_reader(type_length(serial_type)))
+                    for serial_type in serial_types
+                ]
+
+        def _yield_none(page_bytes, pointers):
+            if False:
+                yield
+
+        def _yield_cells(page_type, page_bytes, pointers):
+            yield from (
+                _yield_leaf_table_cells(page_bytes, pointers) if page_type == LEAF_TABLE else
+                _yield_none(page_bytes, pointers)
+            )
 
         for page_num, page_bytes, page_reader in page_nums_pages_readers:
             page_type = page_reader(1)
@@ -190,10 +198,7 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                 raise ValueError('Freeblock found, but are not supported')
 
             pointers = tuple(reversed(Struct('>{}H'.format(num_cells)).unpack(page_reader(num_cells * 2)))) + (page_size,)
-            yield page_num, [
-                cell
-                for cell in _yield_cells(pointers)
-            ]
+            yield page_num, list(_yield_cells(page_type, page_bytes, pointers))
 
     def master_and_non_master_pages_cells(page_cells):
 
@@ -205,14 +210,15 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
             with sqlite3.connect(':memory:') as con:
                 cur = con.cursor()
 
-                return {
-                    cell[1]: {
-                        'columns': schema(cur, cell[1].decode(), cell[4].decode()),
+                return [
+                    {
+                        'name': cell[1],
+                        'info': schema(cur, cell[1].decode(), cell[4].decode()),
                         'root_page': cell[3],
                     }
                     for cell in cells
                     if cell[0] == b'table'
-                }
+                ]
 
         _, master_cells = next(page_cells)
         master_table = parse_master_table_cells(master_cells)
@@ -225,13 +231,15 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
 
     for page_num, cells in non_master_pages_cells:
         table_name = None
-        for _table_name, table in master_table.items():
-            if table['root_page'] == page_num:
-                table_name = _table_name
+        table_info = None
+        for _table in master_table:
+            if _table['root_page'] == page_num:
+                table_name = _table['name']
+                table_info = _table['info']
 
-        yield table_name, [
+        yield table_name, table_info, [
             {
-                master_table[table_name]['columns'][i]['name']: value
+                table_info[i]['name']: value
                 for i, value in enumerate(cell)
             }
             for cell in cells
